# Variables

::: lume_model.variables
    options:
        members:
            - Variable
            - ScalarVariable
            - InputVariable
            - OutputVariable
            - ScalarInputVariable
            - ScalarOutputVariable
